package com.fuint.common.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fuint.framework.pagination.PaginationRequest;
import com.fuint.framework.pagination.PaginationResponse;
import com.fuint.repository.model.MtCurrency;
import com.fuint.framework.exception.BusinessCheckException;
import java.util.List;
import java.util.Map;

/**
 * 货币表业务接口
 *
 * Created by pzg
 * CopyRight https://www.fuint.cn
 */
public interface CurrencyService extends IService<MtCurrency> {

    /**
     * 分页查询列表
     *
     * @param paginationRequest
     * @return
     */
    PaginationResponse<MtCurrency> queryCurrencyListByPagination(PaginationRequest paginationRequest) throws BusinessCheckException;

    /**
     * 添加货币表
     *
     * @param  mtCurrency
     * @throws BusinessCheckException
     * @return
     */
    MtCurrency addCurrency(MtCurrency mtCurrency) throws BusinessCheckException;

    /**
     * 根据ID获取货币表信息
     *
     * @param id ID
     * @throws BusinessCheckException
     * @return
     */
    MtCurrency queryCurrencyById(Long id) throws BusinessCheckException;

    /**
     * 根据ID删除货币表
     *
     * @param id ID
     * @param operator 操作人
     * @throws BusinessCheckException
     * @return
     */
    void deleteCurrency(Long id, String operator) throws BusinessCheckException;

    /**
     * 更新货币表
     * @param  mtCurrency
     * @throws BusinessCheckException
     * @return
     * */
    MtCurrency updateCurrency(MtCurrency mtCurrency) throws BusinessCheckException;

    /**
     * 根据条件搜索货币表
     *
     * @param params 查询参数
     * @throws BusinessCheckException
     * @return
     * */
    List<MtCurrency> queryCurrencyListByParams(Map<String, Object> params) throws BusinessCheckException;
}
